@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -36,7 +36,6 @@ warnings.filterwarnings(action="ignore", category=DeprecationWarning)
 from lib.core.data import logger
 
 try:
-    from lib.controller.controller import start
     from lib.core.common import banner
     from lib.core.common import checkIntegrity
     from lib.core.common import createGithubIssue
@@ -58,15 +57,12 @@ try:
     from lib.core.exception import SqlmapUserQuitException
     from lib.core.option import initOptions
     from lib.core.option import init
-    from lib.core.profiling import profile
     from lib.core.settings import GIT_PAGE
     from lib.core.settings import IS_WIN
     from lib.core.settings import LEGAL_DISCLAIMER
     from lib.core.settings import THREAD_FINALIZATION_TIMEOUT
     from lib.core.settings import UNICODE_ENCODING
     from lib.core.settings import VERSION
-    from lib.core.testing import smokeTest
-    from lib.core.testing import liveTest
     from lib.parse.cmdline import cmdLineParser
 except KeyboardInterrupt:
     errMsg = "user aborted"
@@ -144,22 +140,28 @@ def main():
 
         init()
 
-        if conf.profile:
-            profile()
-        elif conf.smokeTest:
-            smokeTest()
-        elif conf.liveTest:
-            liveTest()
-        else:
-            try:
-                start()
-            except thread.error as ex:
-                if "can't start new thread" in getSafeExString(ex):
-                    errMsg = "unable to start new threads. Please check OS (u)limits"
-                    logger.critical(errMsg)
-                    raise SystemExit
-                else:
-                    raise
+        if not conf.updateAll:
+            # Postponed imports (faster start)
+            if conf.profile:
+                from lib.core.profiling import profile
+                profile()
+            elif conf.smokeTest:
+                from lib.core.testing import smokeTest
+                smokeTest()
+            elif conf.liveTest:
+                from lib.core.testing import liveTest
+                liveTest()
+            else:
+                from lib.controller.controller import start
+                try:
+                    start()
+                except thread.error as ex:
+                    if "can't start new thread" in getSafeExString(ex):
+                        errMsg = "unable to start new threads. Please check OS (u)limits"
+                        logger.critical(errMsg)
+                        raise SystemExit
+                    else:
+                        raise
 
     except SqlmapUserQuitException:
         errMsg = "user quit"
@@ -262,6 +264,12 @@ def main():
                 logger.error(errMsg)
                 raise SystemExit
 
+            elif all(_ in excMsg for _ in ("twophase", "sqlalchemy")):
+                errMsg = "please update the 'sqlalchemy' package"
+                errMsg += "(Reference: https://github.com/apache/incubator-superset/issues/3447)"
+                logger.error(errMsg)
+                raise SystemExit
+
             elif "can't start new thread" in excMsg:
                 errMsg = "there has been a problem while creating new thread instance. "
                 errMsg += "Please make sure that you are not running too many processes"
@@ -289,6 +297,14 @@ def main():
                 logger.error(errMsg)
                 raise SystemExit
 
+            elif "url = url.strip()" in excMsg:
+                dataToStdout(excMsg)
+                print
+                errMsg = "please contact 'miroslav@sqlmap.org' with details for this issue "
+                errMsg += "as he is trying to reproduce it for long time"
+                logger.error(errMsg)
+                raise SystemExit
+
             elif "valueStack.pop" in excMsg and kb.get("dumpKeyboardInterrupt"):
                 raise SystemExit
 
@@ -373,3 +389,6 @@ def main():
 
 if __name__ == "__main__":
     main()
+else:
+    # cancelling postponed imports (because of Travis CI checks)
+    from lib.controller.controller import start
\ No newline at end of file
